ucampurestorage.tests package — ucampurestorage 1.0.1 documentation

# ucampurestorage.tests package

## Submodules

## ucampurestorage.tests.test_httpclient module

ucampurestorage.tests.test_httpclient.httpconnect() → HttpClient

ucampurestorage.tests.test_httpclient.test_http_check_token(httpconnect) → None

ucampurestorage.tests.test_httpclient.test_http_check_url(httpconnect) → None

ucampurestorage.tests.test_httpclient.test_http_format_url(httpconnect, base) → None

## ucampurestorage.tests.test_process module

ucampurestorage.tests.test_process.init_ps() → Process

ucampurestorage.tests.test_process.test_process_daemon_reload(init_ps, version, expected)

ucampurestorage.tests.test_process.test_process_generate_devicemapper_alias(init_ps, return_val, expected) → None

ucampurestorage.tests.test_process.test_process_get_fsdevice_from_mountpoint(init_ps, return_vals, mtpt, mt_check, expected) → None

ucampurestorage.tests.test_process.test_process_get_index_in_list(init_ps, feed_list, expected) → None

ucampurestorage.tests.test_process.test_process_get_mpath_from_mountpoint(init_ps, return_val, expected) → None

ucampurestorage.tests.test_process.test_process_get_multipath_raw_devices(init_ps)

ucampurestorage.tests.test_process.test_process_get_wwid_from_wwn() → None

ucampurestorage.tests.test_process.test_process_get_wwn_from_mpath() → None

ucampurestorage.tests.test_process.test_process_hostname(init_ps, return_vals) → None

ucampurestorage.tests.test_process.test_process_is_device_valid(init_ps, device, expected) → None

ucampurestorage.tests.test_process.test_process_is_wwn_mounted(init_ps, wwn_mpath, wwn_valid, return_val, expected) → None

ucampurestorage.tests.test_process.test_process_is_wwn_serial_valid(init_ps, wwn, expected) → None

ucampurestorage.tests.test_process.test_process_is_wwn_valid(init_ps, wwn, expected) → None

ucampurestorage.tests.test_process.test_process_mount(init_ps, fs, rc, expected)

ucampurestorage.tests.test_process.test_process_mountpoint_exists(init_ps, return_vals, expected) → None

ucampurestorage.tests.test_process.test_process_reload_multipathd(init_ps, version, expected)

ucampurestorage.tests.test_process.test_process_rescan_scsibus() → None

ucampurestorage.tests.test_process.test_process_unmount(init_ps, fs, rc, expected)

## ucampurestorage.tests.test_pureconnection module

ucampurestorage.tests.test_pureconnection.init_pure() → PureAdvanceConnection

ucampurestorage.tests.test_pureconnection.test_pureconnect__check_result(init_pure, input, expected) → None

ucampurestorage.tests.test_pureconnection.test_pureconnect_converttobytes(input, expected, unit) → None

ucampurestorage.tests.test_pureconnection.test_pureconnect_get_controllers(init_pure, fetched) → None

ucampurestorage.tests.test_pureconnection.test_pureconnect_get_json(caplog, init_pure) → None

ucampurestorage.tests.test_pureconnection.test_pureconnect_get_json_exception(caplog, init_pure) → None

ucampurestorage.tests.test_pureconnection.test_pureconnect_totalbytes(input, expected) → None

## ucampurestorage.tests.test_tasks module

## ucampurestorage.tests.test_tokencreater module

ucampurestorage.tests.test_tokencreater.test_token__get_access_token(tokenlib) → None

ucampurestorage.tests.test_tokencreater.test_token_token_create_datetime(tokenlib, date, expected) → None

ucampurestorage.tests.test_tokencreater.test_token_token_current_token_modify(tokenlib, date, expected) → None

ucampurestorage.tests.test_tokencreater.test_token_token_generation(tokenlib) → None

ucampurestorage.tests.test_tokencreater.tokenlib() → TokenCreater

## Module contents